@@ -2,13 +2,15 @@ use strict;
 use warnings;
 package System::Sub;
 {
-  $System::Sub::VERSION = '0.130180';
+  $System::Sub::VERSION = '0.130210';
 }
 
 use File::Which ();
 use Sub::Name 'subname';
 use Symbol 'gensym';
 use IPC::Run qw(start finish);
+use Scalar::Util 1.11 ();  # set_prototype(&$) appeared in 1.11
+
 our @CARP_NOT;
 
 use constant DEBUG => !! $ENV{PERL_SYSTEM_SUB_DEBUG};
@@ -44,7 +46,10 @@ sub import
         my $name = shift;
         # Must be a scalar
         _croak "invalid arg: SCALAR expected" unless defined ref $name && ! ref $name;
-        my $fq_name;
+        my ($fq_name, $proto);
+        if ($name =~ s/\(([^)]*)\)$//s) {
+            $proto = $1;
+        }
         if (index($name, ':') > 0) {
             $fq_name = $name;
             $name = substr($fq_name, 1+rindex($fq_name, ':'));
@@ -65,6 +70,8 @@ sub import
                     _croak 'duplicate @ARGV' if $args;
                     $args = $options;
                     last
+                } elsif ($opt eq '()') {
+                    $proto = shift @$options;
                 } elsif ($opt =~ /^\$?0$/) { # $0
                     $cmd = shift @$options;
                 } elsif ($opt =~ /^\@?ARGV$/) { # @ARGV
@@ -97,6 +104,10 @@ sub import
                 ? _build_sub($name, [ $cmd, ($args ? @$args : ())], \%options)
                 : sub { _croak "'$name' not found in PATH" };
 
+        # As set_prototype *has* a prototype, we have to workaround it
+        # with '&'
+        &Scalar::Util::set_prototype($sub, $proto) if defined $proto;
+
         no strict 'refs';
         *{$fq_name} = subname $fq_name, $sub;
     }
@@ -193,7 +204,7 @@ System::Sub - Wrap external command with a DWIM sub
 
 =head1 VERSION
 
-version 0.130180
+version 0.130210
 
 =head1 SYNOPSIS
 
@@ -238,6 +249,13 @@ version 0.130180
         }
     }
 
+    # Import with a prototype (see perlsub)
+    use System::Sub 'hostname()';  # Empty prototype: no args allowed
+    use strict;
+    # This will fail at compile time with "Too many arguments"
+    hostname("xx");
+
+
 =head1 DESCRIPTION
 
 See also C<L<System::Sub::AutoLoad>> for even simpler usage.
@@ -298,6 +316,10 @@ The sigil (C<$>, C<@>, C<%>) is optional.
 
 =item *
 
+C<()>: prototype of the sub. See L<perlsub/Prototypes>.
+
+=item *
+
 C<$0>: the path to the executable file. It will be expanded from PATH if it
 doesn't contain a directory separator.
 
